@@ -317,7 +317,7 @@ class TalosProducer(object):
                                        + " not found")
 
         self.partitionNumber = response.topicAttribute.partitionNumber
-        self.curPartitionId = random.randint(0, self.partitionNumber)
+        self.curPartitionId = random.randint(0, self.partitionNumber-1)
         self.topicTalosResourceName = topicTalosResourceName
 
     def init_partition_sender(self):
